/*
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016, NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

#ifndef _FSL_INPUTMUX_CONNECTIONS_
#define _FSL_INPUTMUX_CONNECTIONS_

/*******************************************************************************
 * Definitions
 ******************************************************************************/
/* Component ID definition, used by tools. */
#ifndef FSL_COMPONENT_ID
#define FSL_COMPONENT_ID "platform.drivers.inputmux_connections"
#endif

/*!
 * @addtogroup inputmux_driver
 * @{
 */

/*!
 * @name Input multiplexing connections
 * @{
 */

/*! @brief Periphinmux IDs */
#define SCT0_INMUX0         0x00U
#define TIMER0CAPTSEL0      0x20U
#define TIMER1CAPTSEL0      0x40U
#define TIMER2CAPTSEL0      0x60U
#define PINTSEL_PMUX_ID     0xC0U
#define PINTSEL0            0xC0U
#define DMA0_ITRIG_INMUX0   0xE0U
#define DMA0_OTRIG_INMUX0   0x160U
#define FREQMEAS_REF_REG    0x180U
#define FREQMEAS_TARGET_REG 0x184U
#define TIMER3CAPTSEL0      0x1A0U
#define TIMER4CAPTSEL0      0x1C0U
#define PINTSECSEL0         0x1E0U
#define DMA1_ITRIG_INMUX0   0x200U
#define DMA1_OTRIG_INMUX0   0x240U
#define DMA0_REQ_EN0_ID     0x740U
#define DMA0_REQ_EN1_ID     0x744U
#define DMA1_REQ_EN_ID      0x760U
#define DMA0_ITRIG_EN0_ID   0x780U
#define DMA0_ITRIG_EN1_ID   0x784U
#define DMA1_ITRIG_EN_ID    0x7A0U
#define ENA_SHIFT           8U
#define PMUX_SHIFT          20U

/*! @brief INPUTMUX connections type */
typedef enum _inputmux_connection_t
{
    /*!< SCT0 INMUX. */
    kINPUTMUX_SctGpioInAToSct0        = 0U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInBToSct0        = 1U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInCToSct0        = 2U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInDToSct0        = 3U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInEToSct0        = 4U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInFToSct0        = 5U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInGToSct0        = 6U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctGpioInHToSct0        = 7U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer0M0ToSct0         = 8U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer1M0ToSct0         = 9U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer2M0ToSct0         = 10U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer3M0ToSct0         = 11U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer4M0ToSct0         = 12U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToSct0           = 13U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_GpiointBmatchToSct0     = 14U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToSct0   = 15U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToSct0           = 17U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedSck0ToSct0     = 18U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedSck1ToSct0     = 19U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToSct0      = 20U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToSct0      = 21U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_ArmTxevToSct0           = 22U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_DebugHaltedToSct0       = 23U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToSct0           = 24U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0tcomp0ToSct0        = 25U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0tcomp1ToSct0        = 26U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0tcomp2ToSct0        = 27U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0tcomp3ToSct0        = 28U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1tcomp0ToSct0        = 29U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1tcomp1ToSct0        = 30U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1tcomp2ToSct0        = 31U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1tcomp3ToSct0        = 32U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToSct0         = 33U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToSct0         = 34U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToSct0         = 35U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm0MuxTrig01ToSct0  = 36U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm1MuxTrig01ToSct0  = 37U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm2MuxTrig01ToSct0  = 38U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm3MuxTrig01ToSct0  = 39U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm0MuxTrig01ToSct0  = 40U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm1MuxTrig01ToSct0  = 41U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm2MuxTrig01ToSct0  = 42U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm3MuxTrig01ToSct0  = 43U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToSct0   = 44U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToSct0   = 45U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToSct0          = 46U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToSct0          = 47U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToSct0          = 48U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToSct0          = 49U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToSct0          = 50U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToSct0          = 51U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToSct0          = 52U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToSct0          = 53U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Fc3SckToSct0            = 54U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Fc3RxdSdaMosiDataToSct0 = 55U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Fc3TxdSclMisoWsToSct0   = 55U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Fc3CtsDsaSsel0ToSct0    = 57U + (SCT0_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToSct0           = 58U + (SCT0_INMUX0 << PMUX_SHIFT),

    /*!< TIMER0 CAPTSEL. */
    kINPUTMUX_CtimerInp0ToTimer0Captsel       = 0U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp1ToTimer0Captsel       = 1U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp2ToTimer0Captsel       = 2U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp3ToTimer0Captsel       = 3U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp4ToTimer0Captsel       = 4U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp5ToTimer0Captsel       = 5U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp6ToTimer0Captsel       = 6U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp7ToTimer0Captsel       = 7U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp8ToTimer0Captsel       = 8U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp9ToTimer0Captsel       = 9U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp10ToTimer0Captsel      = 10U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp11ToTimer0Captsel      = 11U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp12ToTimer0Captsel      = 12U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp13ToTimer0Captsel      = 13U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp14ToTimer0Captsel      = 14U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp15ToTimer0Captsel      = 15U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp16ToTimer0Captsel      = 16U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp17ToTimer0Captsel      = 17U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp18ToTimer0Captsel      = 18U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp19ToTimer0Captsel      = 19U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToTimer0Captsel  = 20U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToTimer0Captsel          = 22U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToTimer0Captsel     = 23U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToTimer0Captsel     = 24U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToTimer0Captsel          = 25U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToTimer0Captsel          = 26U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToTimer0Captsel        = 27U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToTimer0Captsel        = 28U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToTimer0Captsel        = 29U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm0MuxTrig01ToTimer0Captsel = 30U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm1MuxTrig01ToTimer0Captsel = 31U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm2MuxTrig01ToTimer0Captsel = 32U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm3MuxTrig01ToTimer0Captsel = 33U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm0MuxTrig01ToTimer0Captsel = 34U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm1MuxTrig01ToTimer0Captsel = 35U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm2MuxTrig01ToTimer0Captsel = 36U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm3MuxTrig01ToTimer0Captsel = 37U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToTimer0Captsel  = 38U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToTimer0Captsel  = 39U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToTimer0Captsel         = 40U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToTimer0Captsel         = 41U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToTimer0Captsel         = 42U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToTimer0Captsel         = 43U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToTimer0Captsel         = 44U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToTimer0Captsel         = 45U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToTimer0Captsel         = 46U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToTimer0Captsel         = 47U + (TIMER0CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToTimer0Captsel          = 48U + (TIMER0CAPTSEL0 << PMUX_SHIFT),

    /*!< TIMER1 CAPTSEL. */
    kINPUTMUX_CtimerInp0ToTimer1Captsel       = 0U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp1ToTimer1Captsel       = 1U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp2ToTimer1Captsel       = 2U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp3ToTimer1Captsel       = 3U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp4ToTimer1Captsel       = 4U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp5ToTimer1Captsel       = 5U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp6ToTimer1Captsel       = 6U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp7ToTimer1Captsel       = 7U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp8ToTimer1Captsel       = 8U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp9ToTimer1Captsel       = 9U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp10ToTimer1Captsel      = 10U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp11ToTimer1Captsel      = 11U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp12ToTimer1Captsel      = 12U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp13ToTimer1Captsel      = 13U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp14ToTimer1Captsel      = 14U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp15ToTimer1Captsel      = 15U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp16ToTimer1Captsel      = 16U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp17ToTimer1Captsel      = 17U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp18ToTimer1Captsel      = 18U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp19ToTimer1Captsel      = 19U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToTimer1Captsel  = 20U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToTimer1Captsel          = 22U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToTimer1Captsel     = 23U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToTimer1Captsel     = 24U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToTimer1Captsel          = 25U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToTimer1Captsel          = 26U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToTimer1Captsel        = 27U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToTimer1Captsel        = 28U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToTimer1Captsel        = 29U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm0MuxTrig01ToTimer1Captsel = 30U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm1MuxTrig01ToTimer1Captsel = 31U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm2MuxTrig01ToTimer1Captsel = 32U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm3MuxTrig01ToTimer1Captsel = 33U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm0MuxTrig01ToTimer1Captsel = 34U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm1MuxTrig01ToTimer1Captsel = 35U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm2MuxTrig01ToTimer1Captsel = 36U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm3MuxTrig01ToTimer1Captsel = 37U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToTimer1Captsel  = 38U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToTimer1Captsel  = 39U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToTimer1Captsel         = 40U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToTimer1Captsel         = 41U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToTimer1Captsel         = 42U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToTimer1Captsel         = 43U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToTimer1Captsel         = 44U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToTimer1Captsel         = 45U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToTimer1Captsel         = 46U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToTimer1Captsel         = 47U + (TIMER1CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToTimer1Captsel          = 48U + (TIMER1CAPTSEL0 << PMUX_SHIFT),

    /*!< TIMER2 CAPTSEL. */
    kINPUTMUX_CtimerInp0ToTimer2Captsel       = 0U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp1ToTimer2Captsel       = 1U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp2ToTimer2Captsel       = 2U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp3ToTimer2Captsel       = 3U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp4ToTimer2Captsel       = 4U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp5ToTimer2Captsel       = 5U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp6ToTimer2Captsel       = 6U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp7ToTimer2Captsel       = 7U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp8ToTimer2Captsel       = 8U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp9ToTimer2Captsel       = 9U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp10ToTimer2Captsel      = 10U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp11ToTimer2Captsel      = 11U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp12ToTimer2Captsel      = 12U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp13ToTimer2Captsel      = 13U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp14ToTimer2Captsel      = 14U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp15ToTimer2Captsel      = 15U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp16ToTimer2Captsel      = 16U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp17ToTimer2Captsel      = 17U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp18ToTimer2Captsel      = 18U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp19ToTimer2Captsel      = 19U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToTimer2Captsel  = 20U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToTimer2Captsel          = 22U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToTimer2Captsel     = 23U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToTimer2Captsel     = 24U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToTimer2Captsel          = 25U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToTimer2Captsel          = 26U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToTimer2Captsel        = 27U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToTimer2Captsel        = 28U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToTimer2Captsel        = 29U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm0MuxTrig01ToTimer2Captsel = 30U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm1MuxTrig01ToTimer2Captsel = 31U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm2MuxTrig01ToTimer2Captsel = 32U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0Sm3MuxTrig01ToTimer2Captsel = 33U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm0MuxTrig01ToTimer2Captsel = 34U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm1MuxTrig01ToTimer2Captsel = 35U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm2MuxTrig01ToTimer2Captsel = 36U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1Sm3MuxTrig01ToTimer2Captsel = 37U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToTimer2Captsel  = 38U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToTimer2Captsel  = 39U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToTimer2Captsel         = 40U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToTimer2Captsel         = 41U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToTimer2Captsel         = 42U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToTimer2Captsel         = 43U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToTimer2Captsel         = 44U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToTimer2Captsel         = 45U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToTimer2Captsel         = 46U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToTimer2Captsel         = 47U + (TIMER2CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToTimer2Captsel          = 48U + (TIMER2CAPTSEL0 << PMUX_SHIFT),

    /*!< Pin interrupt select. */
    kINPUTMUX_GpioPort0Pin0ToPintsel  = 0U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin1ToPintsel  = 1U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin2ToPintsel  = 2U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin3ToPintsel  = 3U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin4ToPintsel  = 4U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin5ToPintsel  = 5U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin6ToPintsel  = 6U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin7ToPintsel  = 7U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin8ToPintsel  = 8U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin9ToPintsel  = 9U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin10ToPintsel = 10U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin11ToPintsel = 11U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin12ToPintsel = 12U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin13ToPintsel = 13U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin14ToPintsel = 14U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin15ToPintsel = 15U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin16ToPintsel = 16U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin17ToPintsel = 17U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin18ToPintsel = 18U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin19ToPintsel = 19U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin20ToPintsel = 20U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin21ToPintsel = 21U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin22ToPintsel = 22U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin23ToPintsel = 23U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin24ToPintsel = 24U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin25ToPintsel = 25U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin26ToPintsel = 26U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin27ToPintsel = 27U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin28ToPintsel = 28U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin29ToPintsel = 29U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin30ToPintsel = 30U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin31ToPintsel = 31U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin0ToPintsel  = 32U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin1ToPintsel  = 33U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin2ToPintsel  = 34U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin3ToPintsel  = 35U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin4ToPintsel  = 36U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin5ToPintsel  = 37U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin6ToPintsel  = 38U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin7ToPintsel  = 39U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin8ToPintsel  = 40U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin9ToPintsel  = 41U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin10ToPintsel = 42U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin11ToPintsel = 43U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin12ToPintsel = 44U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin13ToPintsel = 45U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin14ToPintsel = 46U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin15ToPintsel = 47U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin16ToPintsel = 48U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin17ToPintsel = 49U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin18ToPintsel = 50U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin19ToPintsel = 51U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin20ToPintsel = 52U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin21ToPintsel = 53U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin22ToPintsel = 54U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin23ToPintsel = 55U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin24ToPintsel = 56U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin25ToPintsel = 57U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin26ToPintsel = 58U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin27ToPintsel = 59U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin28ToPintsel = 60U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin29ToPintsel = 61U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin30ToPintsel = 62U + (PINTSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort1Pin31ToPintsel = 63U + (PINTSEL0 << PMUX_SHIFT),

    /*!< DMA0 Input trigger. */
    kINPUTMUX_FlexSpiRxToDma0        = 0U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexSpiTxToDma0        = 1U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt0ToDma0          = 2U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt1ToDma0          = 3U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt2ToDma0          = 4U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt3ToDma0          = 5U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer0M0ToDma0        = 6U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer0M1ToDma0        = 7U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer1M0ToDma0        = 8U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer1M1ToDma0        = 9U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer2M0ToDma0        = 10U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer2M1ToDma0        = 11U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer3M0ToDma0        = 12U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer3M1ToDma0        = 13U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer4M0ToDma0        = 14U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer4M1ToDma0        = 15U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToDma0          = 16U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigAToDma0           = 17U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigBToDma0           = 18U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigCToDma0           = 19U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigDToDma0           = 20U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctDma0ToDma0          = 21U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_SctDma1ToDma0          = 22U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc0Tcomp0ToDma0       = 23U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Adc1Tcomp0ToDma0       = 24U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0ToDma0           = 25U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1ToDma0           = 26U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2ToDma0           = 27U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToDma0         = 28U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToDma0         = 29U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToDma0         = 30U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToDma0         = 31U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToDma0         = 32U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToDma0         = 33U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToDma0         = 34U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToDma0         = 35U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt0ToDma0 = 36U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt1ToDma0 = 37U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt2ToDma0 = 38U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt3ToDma0 = 39U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal0ToDma0  = 40U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal1ToDma0  = 41U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal2ToDma0  = 42U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal3ToDma0  = 43U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt0ToDma0 = 44U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt1ToDma0 = 45U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt2ToDma0 = 46U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt3ToDma0 = 47U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal0ToDma0  = 48U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal1ToDma0  = 49U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal2ToDma0  = 50U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal3ToDma0  = 51U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToDma0          = 52U + (DMA0_ITRIG_INMUX0 << PMUX_SHIFT),

    /*!< DMA0 output trigger. */
    kINPUTMUX_Dma0FlexSpiRxTrigoutToTriginChannels        = 0U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexSpiTxTrigoutToTriginChannels        = 1U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0PinInt0TrigoutToTriginChannels          = 2U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0PinInt1TrigoutToTriginChannels          = 3U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0PinInt2TrigoutToTriginChannels          = 4U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0PinInt3TrigoutToTriginChannels          = 5U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer0M0TrigoutToTriginChannels        = 6U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer0M1TrigoutToTriginChannels        = 7U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer1M0TrigoutToTriginChannels        = 8U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer1M1TrigoutToTriginChannels        = 9U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer2M0TrigoutToTriginChannels        = 10U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer2M1TrigoutToTriginChannels        = 11U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer3M0TrigoutToTriginChannels        = 12U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer3M1TrigoutToTriginChannels        = 13U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer4M0TrigoutToTriginChannels        = 14U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Ctimer4M1TrigoutToTriginChannels        = 15U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0CompOutTrigoutToTriginChannels          = 16U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0OtrigATrigoutToTriginChannels           = 17U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0OtrigBTrigoutToTriginChannels           = 18U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0OtrigCTrigoutToTriginChannels           = 19U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0OtrigDTrigoutToTriginChannels           = 20U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0SctDma0TrigoutToTriginChannels          = 21U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0SctDma1TrigoutToTriginChannels          = 22U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Adc0Tcomp0TrigoutToTriginChannels       = 23U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Adc1Tcomp0TrigoutToTriginChannels       = 24U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Hscmp0TrigoutToTriginChannels           = 25U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Hscmp1TrigoutToTriginChannels           = 26U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Hscmp2TrigoutToTriginChannels           = 27U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi0Out0TrigoutToTriginChannels         = 28U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi0Out1TrigoutToTriginChannels         = 29U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi0Out2TrigoutToTriginChannels         = 30U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi0Out3TrigoutToTriginChannels         = 31U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi1Out0TrigoutToTriginChannels         = 32U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi1Out1TrigoutToTriginChannels         = 33U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi1Out2TrigoutToTriginChannels         = 34U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0Aoi1Out3TrigoutToTriginChannels         = 35U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqCapt0TrigoutToTriginChannels = 36U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqCapt1TrigoutToTriginChannels = 37U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqCapt2TrigoutToTriginChannels = 38U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqCapt3TrigoutToTriginChannels = 39U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqVal0TrigoutToTriginChannels  = 40U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqVal1TrigoutToTriginChannels  = 41U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqVal2TrigoutToTriginChannels  = 42U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm0ReqVal3TrigoutToTriginChannels  = 43U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqCapt0TrigoutToTriginChannels = 44U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqCapt1TrigoutToTriginChannels = 45U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqCapt2TrigoutToTriginChannels = 46U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqCapt3TrigoutToTriginChannels = 47U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqVal0TrigoutToTriginChannels  = 48U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqVal1TrigoutToTriginChannels  = 49U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqVal2TrigoutToTriginChannels  = 50U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma0FlexPwm1ReqVal3TrigoutToTriginChannels  = 51U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutTrigoutToTriginChannels              = 52U + (DMA0_OTRIG_INMUX0 << PMUX_SHIFT),

    /*!< Selection for frequency measurement reference clock. */
    kINPUTMUX_ClkInToFreqmeasRef    = 0U + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_Fro12MhzToFreqmeasRef = 1u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_WdtOscToFreqmeasRef   = 2u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_32KhzOscToFreqmeasRef = 3u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_MainClkToFreqmeasRef  = 4u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_4ToFreqmeasRef   = 5u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_20ToFreqmeasRef  = 6u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_24ToFreqmeasRef  = 7u + (FREQMEAS_REF_REG << PMUX_SHIFT),
    kINPUTMUX_Pio1_4ToFreqmeasRef   = 8u + (FREQMEAS_REF_REG << PMUX_SHIFT),

    /*!< Selection for frequency measurement target clock. */
    kINPUTMUX_ClkInToFreqmeasTarget    = 0U + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_Fro12MhzToFreqmeasTarget = 1u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_WdtOscToFreqmeasTarget   = 2u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_32KhzOscToFreqmeasTarget = 3u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_MainClkToFreqmeasTarget  = 4u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_4ToFreqmeasTarget   = 5u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_20ToFreqmeasTarget  = 6u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_Pio0_24ToFreqmeasTarget  = 7u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),
    kINPUTMUX_Pio1_4ToFreqmeasTarget   = 8u + (FREQMEAS_TARGET_REG << PMUX_SHIFT),

    /*!< TIMER3 CAPTSEL. */
    kINPUTMUX_CtimerInp0ToTimer3Captsel      = 0U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp1ToTimer3Captsel      = 1U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp2ToTimer3Captsel      = 2U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp3ToTimer3Captsel      = 3U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp4ToTimer3Captsel      = 4U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp5ToTimer3Captsel      = 5U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp6ToTimer3Captsel      = 6U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp7ToTimer3Captsel      = 7U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp8ToTimer3Captsel      = 8U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp9ToTimer3Captsel      = 9U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp10ToTimer3Captsel     = 10U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp11ToTimer3Captsel     = 11U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp12ToTimer3Captsel     = 12U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp13ToTimer3Captsel     = 13U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp14ToTimer3Captsel     = 14U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp15ToTimer3Captsel     = 15U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp16ToTimer3Captsel     = 16U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp17ToTimer3Captsel     = 17U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp18ToTimer3Captsel     = 18U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp19ToTimer3Captsel     = 19U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToTimer3Captsel = 20U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToTimer3Captsel         = 22U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToTimer3Captsel    = 23U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToTimer3Captsel    = 24U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToTimer3Captsel         = 25U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToTimer3Captsel         = 26U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToTimer3Captsel       = 27U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToTimer3Captsel       = 28U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToTimer3Captsel       = 29U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A0Trig01ToTimer3Captsel    = 30U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A1Trig01ToTimer3Captsel    = 31U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A2Trig01ToTimer3Captsel    = 32U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A3Trig01ToTimer3Captsel    = 33U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A0Trig01ToTimer3Captsel    = 34U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A1Trig01ToTimer3Captsel    = 35U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A2Trig01ToTimer3Captsel    = 36U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A3Trig01ToTimer3Captsel    = 37U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToTimer3Captsel = 38U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToTimer3Captsel = 39U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToTimer3Captsel        = 40U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToTimer3Captsel        = 41U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToTimer3Captsel        = 42U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToTimer3Captsel        = 43U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToTimer3Captsel        = 44U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToTimer3Captsel        = 45U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToTimer3Captsel        = 46U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToTimer3Captsel        = 47U + (TIMER3CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToTimer3Captsel         = 48U + (TIMER3CAPTSEL0 << PMUX_SHIFT),

    /*!< Timer4 CAPTSEL. */
    kINPUTMUX_CtimerInp0ToTimer4Captsel      = 0U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp1ToTimer4Captsel      = 1U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp2ToTimer4Captsel      = 2U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp3ToTimer4Captsel      = 3U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp4ToTimer4Captsel      = 4U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp5ToTimer4Captsel      = 5U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp6ToTimer4Captsel      = 6U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp7ToTimer4Captsel      = 7U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp8ToTimer4Captsel      = 8U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp9ToTimer4Captsel      = 9U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp10ToTimer4Captsel     = 10U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp11ToTimer4Captsel     = 11U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp12ToTimer4Captsel     = 12U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp13ToTimer4Captsel     = 13U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp14ToTimer4Captsel     = 14U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp15ToTimer4Captsel     = 15U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp16ToTimer4Captsel     = 16U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp17ToTimer4Captsel     = 17U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp18ToTimer4Captsel     = 18U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CtimerInp19ToTimer4Captsel     = 19U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Usb0FrameToggleToTimer4Captsel = 20U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_CompOutToTimer4Captsel         = 22U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs0ToTimer4Captsel    = 23U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_I2sSharedWs1ToTimer4Captsel    = 24U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc0IrqToTimer4Captsel         = 25U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Adc1IrqToTimer4Captsel         = 26U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp0OutToTimer4Captsel       = 27U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp1OutToTimer4Captsel       = 28U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Hscmp2OutToTimer4Captsel       = 29U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A0Trig01ToTimer4Captsel    = 30U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A1Trig01ToTimer4Captsel    = 31U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A2Trig01ToTimer4Captsel    = 32U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm0A3Trig01ToTimer4Captsel    = 33U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A0Trig01ToTimer4Captsel    = 34U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A1Trig01ToTimer4Captsel    = 35U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A2Trig01ToTimer4Captsel    = 36U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Pwm1A3Trig01ToTimer4Captsel    = 37U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc0CmpPosMatchToTimer4Captsel = 38U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Enc1CmpPosMatchToTimer4Captsel = 39U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToTimer4Captsel        = 40U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToTimer4Captsel        = 41U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToTimer4Captsel        = 42U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToTimer4Captsel        = 43U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToTimer4Captsel        = 44U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToTimer4Captsel        = 45U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToTimer4Captsel        = 46U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToTimer4Captsel        = 47U + (TIMER4CAPTSEL0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToTimer4Captsel         = 48U + (TIMER4CAPTSEL0 << PMUX_SHIFT),

    /*Pin interrupt secure select */
    kINPUTMUX_GpioPort0Pin0ToPintSecsel  = 0U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin1ToPintSecsel  = 1U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin2ToPintSecsel  = 2U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin3ToPintSecsel  = 3U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin4ToPintSecsel  = 4U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin5ToPintSecsel  = 5U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin6ToPintSecsel  = 6U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin7ToPintSecsel  = 7U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin8ToPintSecsel  = 8U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin9ToPintSecsel  = 9U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin10ToPintSecsel = 10U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin11ToPintSecsel = 11U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin12ToPintSecsel = 12U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin13ToPintSecsel = 13U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin14ToPintSecsel = 14U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin15ToPintSecsel = 15U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin16ToPintSecsel = 16U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin17ToPintSecsel = 17U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin18ToPintSecsel = 18U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin19ToPintSecsel = 19U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin20ToPintSecsel = 20U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin21ToPintSecsel = 21U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin22ToPintSecsel = 22U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin23ToPintSecsel = 23U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin24ToPintSecsel = 24U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin25ToPintSecsel = 25U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin26ToPintSecsel = 26U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin27ToPintSecsel = 27U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin28ToPintSecsel = 28U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin29ToPintSecsel = 29U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin30ToPintSecsel = 30U + (PINTSECSEL0 << PMUX_SHIFT),
    kINPUTMUX_GpioPort0Pin31ToPintSecsel = 31U + (PINTSECSEL0 << PMUX_SHIFT),

    /*!< DMA1 Input trigger. */
    kINPUTMUX_PinInt0ToDma1     = 0U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt1ToDma1     = 1U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt2ToDma1     = 2U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_PinInt3ToDma1     = 3U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer0M0ToDma1   = 4U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer0M1ToDma1   = 5U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer2M0ToDma1   = 6U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Ctimer4M0ToDma1   = 7U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigAToDma1      = 8U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigBToDma1      = 9U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigCToDma1      = 10U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_OtrigDToDma1      = 11U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Sct0DmaReq0ToDma1 = 12U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Sct0DmaReq1ToDma1 = 13U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexSpiRxToDma1   = 14U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_FlexSpiTxToDma1   = 15U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out0ToDma1    = 16U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out1ToDma1    = 17U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out2ToDma1    = 18U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi0Out3ToDma1    = 19U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out0ToDma1    = 20U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out1ToDma1    = 21U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out2ToDma1    = 22U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Aoi1Out3ToDma1    = 23U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_TmprOutToDma1     = 24U + (DMA1_ITRIG_INMUX0 << PMUX_SHIFT),

    /*!< DMA1 output trigger. */
    kINPUTMUX_Dma1HsLspiRxTrigoutToTriginChannels   = 2U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1HsLspiTxTrigoutToTriginChannels   = 3U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom0RxTrigoutToTriginChannels = 4U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom0TxTrigoutToTriginChannels = 5U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom1RxTrigoutToTriginChannels = 6U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom1TxTrigoutToTriginChannels = 7U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom3RxTrigoutToTriginChannels = 8U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Flexcom3TxTrigoutToTriginChannels = 9U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Dmic0Ch0TrigoutToTriginChannels   = 10U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1Dmic0Ch1TrigoutToTriginChannels   = 11U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1I3c0RxTrigoutToTriginChannels     = 12U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
    kINPUTMUX_Dma1I3c0TxTrigoutToTriginChannels     = 13U + (DMA1_OTRIG_INMUX0 << PMUX_SHIFT),
} inputmux_connection_t;

/*! @brief INPUTMUX signal enable/disable type */
typedef enum _inputmux_signal_t
{
    /*!< DMA0 REQ(DMA0_REQEN0) signal. */
    kINPUTMUX_FlexSpiRxToDmac0Ch0RequestEna   = 0U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_FlexSpiTxToDmac0Ch1RequestEna   = 1U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_PinInt0ToDmac0Ch2RequestEna     = 2U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_PinInt1ToDmac0Ch3RequestEna     = 3U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_PinInt2ToDmac0Ch4RequestEna     = 4U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_PinInt3ToDmac0Ch5RequestEna     = 5U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer0M0ToDmac0Ch6RequestEna   = 6U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer0M1ToDmac0Ch7RequestEna   = 7U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer1M0ToDmac0Ch8RequestEna   = 8U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer1M1ToDmac0Ch9RequestEna   = 9U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer2M0ToDmac0Ch10RequestEna  = 10U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer2M1ToDmac0Ch11RequestEna  = 11U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer3M0ToDmac0Ch12RequestEna  = 12U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer3M1ToDmac0Ch13RequestEna  = 13U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer4M0ToDmac0Ch14RequestEna  = 14U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Ctimer4M1ToDmac0Ch15RequestEna  = 15U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_CompOutToDmac0Ch16RequestEna    = 16U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_OtrigAToDmac0Ch17RequestEna     = 17U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_OtrigBToDmac0Ch18RequestEna     = 18U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_OtrigCToDmac0Ch19RequestEna     = 19U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_OtrigDToDmac0Ch20RequestEna     = 20U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_SctDma0ToDmac0Ch21RequestEna    = 21U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_SctDma1ToDmac0Ch22RequestEna    = 22U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Adc0Tcomp0ToDmac23Ch0RequestEna = 23U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Adc1Tcomp0ToDmac24Ch0RequestEna = 24U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Hscmp0ToDmac0Ch25RequestEna     = 25U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Hscmp1ToDmac0Ch26RequestEna     = 26U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Hscmp2ToDmac0Ch27RequestEna     = 27U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Aoi0Out0ToDmac0Ch28RequestEna   = 28U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Aoi0Out1ToDmac0Ch29RequestEna   = 29U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Aoi0Out2ToDmac0Ch30RequestEna   = 30U + (DMA0_REQ_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Aoi0Out3ToDmac0Ch31RequestEna   = 31U + (DMA0_REQ_EN0_ID << ENA_SHIFT),

    /*!< DMA0 REQ(DMA0_REQEN0) signal. */
    kINPUTMUX_Aoi1Out0ToDmac0Ch32RequestEna         = 0U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Aoi1Out1ToDmac0Ch33RequestEna         = 1U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Aoi1Out2ToDmac0Ch34RequestEna         = 2U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Aoi1Out3ToDmac0Ch35RequestEna         = 3U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt0ToDmac0Ch36RequestEna = 4U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt1ToDmac0Ch37RequestEna = 5U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt2ToDmac0Ch38RequestEna = 6U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqCapt3ToDmac0Ch39RequestEna = 7U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal0ToDmac0Ch40RequestEna  = 8U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal1ToDmac0Ch41RequestEna  = 9U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal2ToDmac0Ch42RequestEna  = 10U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm0ReqVal3ToDmac0Ch43RequestEna  = 11U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt0ToDmac0Ch44RequestEna = 12U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt1ToDmac0Ch45RequestEna = 13U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt2ToDmac0Ch46RequestEna = 14U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqCapt3ToDmac0Ch47RequestEna = 15U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal0ToDmac0Ch48RequestEna  = 16U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal1ToDmac0Ch49RequestEna  = 17U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal2ToDmac0Ch50RequestEna  = 18U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_FlexPwm1ReqVal3ToDmac0Ch51RequestEna  = 19U + (DMA0_REQ_EN1_ID << ENA_SHIFT),
    kINPUTMUX_TmprOutToDmac0Ch52RequestEna          = 20U + (DMA0_REQ_EN1_ID << ENA_SHIFT),

    /*!< DMA1 REQ(DMA1_REQEN) signal. */
    kINPUTMUX_HsLspiRxToDmac1Ch2RequestEna   = 2U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_HsLspiTxToDmac1Ch3RequestEna   = 3U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom0RxToDmac1Ch4RequestEna = 4U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom0TxToDmac1Ch5RequestEna = 5U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom1RxToDmac1Ch6RequestEna = 6U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom1TxToDmac1Ch7RequestEna = 7U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom3RxToDmac1Ch8RequestEna = 8U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Flexcom3TxToDmac1Ch9RequestEna = 9U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmic0Ch0ToDmac1Ch10RequestEna  = 10U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmic0Ch1ToDmac1Ch11RequestEna  = 11U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_I3c0RxToDmac1Ch12RequestEna    = 12U + (DMA1_REQ_EN_ID << ENA_SHIFT),
    kINPUTMUX_I3c0TxToDmac1Ch13RequestEna    = 13U + (DMA1_REQ_EN_ID << ENA_SHIFT),

    /*!< DMA0 input trigger(DMA0_ITRIGEN0) source enable. */
    kINPUTMUX_Dmac0InputTriggerFlexSpiRxEna  = 0U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexSpiTxEna  = 1U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerPinInt0Ena    = 2U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerPinInt1Ena    = 3U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerPinInt2Ena    = 4U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerPinInt3Ena    = 5U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer0M0Ena  = 6U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer0M1Ena  = 7U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer1M0Ena  = 8U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer1M1Ena  = 9U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer2M0Ena  = 10U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer2M1Ena  = 11U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer3M0Ena  = 12U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer3M1Ena  = 13U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer4M0Ena  = 14U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCtimer4M1Ena  = 15U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerCompOutEna    = 16U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerOtrigAEna     = 17U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerOtrigBEna     = 18U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerOtrigCEna     = 19U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerOtrigDEna     = 20U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerSctDma0Ena    = 21U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerSctDma1Ena    = 22U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAdc0Tcomp0Ena = 23U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAdc1Tcomp0Ena = 24U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerHscmp0Ena     = 25U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerHscmp1Ena     = 26U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerHscmp2Ena     = 27U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi0Out0Ena   = 28U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi0Out1Ena   = 29U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi0Out2Ena   = 30U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi0Out3Ena   = 31U + (DMA0_ITRIG_EN0_ID << ENA_SHIFT),

    /*!< DMA0 input trigger(DMA0_ITRIGEN1) source enable. */
    kINPUTMUX_Dmac0InputTriggerAoi1Out0Ena         = 0U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi1Out1Ena         = 1U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi1Out2Ena         = 2U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerAoi1Out3Ena         = 3U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqCapt0Ena = 4U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqCapt1Ena = 5U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqCapt2Ena = 6U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqCapt3Ena = 7U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqVal0Ena  = 8U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqVal1Ena  = 9U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqVal2Ena  = 10U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm0ReqVal3Ena  = 11U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqCapt0Ena = 12U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqCapt1Ena = 13U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqCapt2Ena = 14U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqCapt3Ena = 15U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqVal0Ena  = 16U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqVal1Ena  = 17U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqVal2Ena  = 18U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerFlexPwm1ReqVal3Ena  = 19U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),
    kINPUTMUX_Dmac0InputTriggerTmprOutEna          = 20U + (DMA0_ITRIG_EN1_ID << ENA_SHIFT),

    /*!< DMA1 input trigger(DMA1_ITRIGEN) source enable. */
    kINPUTMUX_Dmac1InputTriggerHsLspiRxEna   = 2U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerHsLspiTxEna   = 3U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom0RxEna = 4U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom0TxEna = 5U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom1RxEna = 6U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom1TxEna = 7U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom3RxEna = 8U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerFlexcom3TxEna = 9U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerDmic0Ch0Ena   = 10U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerDmic0Ch1Ena   = 11U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerI3c0RxEna     = 12U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
    kINPUTMUX_Dmac1InputTriggerI3c0TxEna     = 13U + (DMA1_ITRIG_EN_ID << ENA_SHIFT),
} inputmux_signal_t;

/*@}*/

/*@}*/

#endif /* _FSL_INPUTMUX_CONNECTIONS_ */
